==> haskell-tasty-th-0.1.7-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-2dGoLGF43kY4QvNrihvR8V
key: tasty-th-0.1.7-2dGoLGF43kY4QvNrihvR8V
license: BSD-3-Clause
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
abi: 443012747074620d723a0c123e95cbd1
exposed: True
exposed-modules:
    Test.Tasty.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-2dGoLGF43kY4QvNrihvR8V
depends:
    base-4.11.1.0 haskell-src-exts-1.20.2-udiE50EOtSJb0KMyu3jrK
    tasty-1.1.0.1-9gqlJB8eL4NHSFovdnMjrH template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-exts-1.20.2-udiE50EOtSJb0KMyu3jrK=7ee77880d5f860d88355ec2bf205631b
             tasty-1.1.0.1-9gqlJB8eL4NHSFovdnMjrH=f0a93a020d3b5992ce4b7ce7ce328637
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-th-0.1.7-30-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-th.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-th
version: 0.1.7
id: tasty-th-0.1.7-6NFXeWLqXrgHJchacjRpbg
key: tasty-th-0.1.7-6NFXeWLqXrgHJchacjRpbg
license: BSD-3-Clause
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Oscar Finnsson & Emil Nordling & Benno Fünfstück
homepage: http://github.com/bennofs/tasty-th
synopsis: Automatic tasty test case discovery using TH
description:
    Generate tasty TestTrees automatically with TemplateHaskell. See the README for example usage.
category: Testing
abi: 71865fcfef56039a79c7b8bf7cfc6a01
exposed: True
exposed-modules:
    Test.Tasty.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-th-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-th-0.1.7
hs-libraries: HStasty-th-0.1.7-6NFXeWLqXrgHJchacjRpbg
depends:
    base-4.11.1.0 haskell-src-exts-1.20.2-3jrV2c2FGsoJFj57Zt74zH
    tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             haskell-src-exts-1.20.2-3jrV2c2FGsoJFj57Zt74zH=d0056a889997737bb9cb2b39a3b5e872
             tasty-1.1.0.3-47QwUInRtOzF3zSlr6CCJg=2e6555b026876c59a316d2124bf273ef
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
haddock-interfaces: /usr/share/doc/haskell-tasty-th/html/tasty-th.haddock
haddock-html: /usr/share/doc/haskell-tasty-th/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
